library(rjags)

# The coin example
jags.coin <- jags.model('~/jags/b312/coin.bug')

# As you increase the number of simulations,
#   estimate gets closer to the truth
#   Truth for P8 is 0.0547 
jags.samples(jags.coin, c('Y','P8'), 100)
jags.samples(jags.coin, c('Y','P8'), 1000)
jags.samples(jags.coin, c('Y','P8'), 100000)


# Drug example: Monte Carlo predictions
jags.mcpred <- jags.model('~/jags/b312/mcpred.bug')

res.mcpred <- coda.samples(jags.mcpred, c('theta','y','P.crit'), 10000)
summary(res.mcpred)
plot(res.mcpred)

apply(as.matrix(res.mcpred), 2, mean)
apply(as.matrix(res.mcpred) >=15, 2, mean)

#Uncertainty in a power calculation
jags.power <- jags.model('~/jags/b312/power.bug')

res.power <- coda.samples(jags.power, c('n','power','prob70'), 10000)
summary(res.power)
plot(res.power)

# Practicum: Student's t distribution
jags.t <- jags.model('~/jags/b312/t.bug')
res.t <- coda.samples(jags.t, c('y','z'), 10000)
summary(res.t)
plot(res.t)

# Practicum: Cubed Normal
jags.z3 <- jags.model('~/jags/b312/cubedZ.bug')
res.z3 <- coda.samples(jags.z3,c('z','z3'), 10000)
plot(res.z3)
summary(res.z3) 
summary(as.matrix(res.z3)[,1]^3)

# Drug example (with data)
drug.vals <- list(
  'a'=9.2, 'b'=13.8, #prior parameters
  'y'=15, # Number of observed successed
  'n'=20, # Number of observed trials
  'm'=40, # Future number of trials
  'ncrit'=25) # Critical values for future successes
jags.drug <- jags.model('~/jags/b312/drug.bug',
  data=drug.vals)
res.drug <- coda.samples(jags.drug, c('theta','P.crit'),10000)
plot(res.drug)
summary(res.drug)

# Logistic regression for convergence diagnostics
logit.data <- list(
  'dose'=c(seq(1.69,1.81,by=0.03),1.83,1.86,1.88),
  'n'=c(59,60,62,56,63,59,62,60),
  'r'=c(6 ,13,18,28,52,53,61,59),
  'N'=8)

jags.logit1 <- jags.model('~/jags/b312/logit1.bug', data=logit.data, n.chains=2)
update(jags.logit1, 10000)
res.logit1 <- coda.samples(jags.logit1, c('alpha','beta'), 10000)
plot(res.logit1)
autocorr.plot(res.logit1)

jags.logit2 <- jags.model('~/jags/b312/logit2.bug', data=logit.data, n.chains=2)
update(jags.logit2, 10000)
res.logit2 <- coda.samples(jags.logit2, c('alpha','beta'), 10000)
plot(res.logit2)
autocorr.plot(res.logit2)
summary(res.logit2)

glm(cbind(r, n-r) ~ dose, data=logit.data, family=binomial)

######################################
# Linear regression with income data #
######################################

income.data <- read.csv("~/jags/b312/income.csv", header=TRUE)
income.data$rural2 <- as.numeric(income.data$region==2)
income.data$rural3 <- as.numeric(income.data$region==3)
head(income.data)

income.data.jags <- list(income=income.data$income,
 rural2=income.data$rural2,
 rural3=income.data$rural3,
 age=income.data$age,
 N=dim(income.data)[1])

jags.income <- jags.model('~/jags/b312/income.bug', data=income.data.jags)
update(jags.income,1000)
res.income <- coda.samples(jags.income, c('alpha','beta','sigma2','delta2','delta3'), 10000)
plot(res.income)
summary(res.income)

res.income <- coda.samples(jags.income, c('mu'), 10000)
summary(res.income)

summary(lm(income ~ age + factor(region), data=income.data))

jags.incomet <- jags.model('~/jags/b312/incomet.bug', data=income.data.jags)
update(jags.incomet,1000)
res.incomet <- coda.samples(jags.incomet, c('alpha','beta','sigma2','delta2','delta3','k'), 1000)
plot(res.incomet, ask=TRUE)
summary(res.incomet)

income.data.jags.k <- income.data.jags <- list(income=income.data$income,
 rural2=income.data$rural2,
 rural3=income.data$rural3,
 age=income.data$age,
 N=dim(income.data)[1],
 p.df=rep(1,10))

jags.incomet.k <- jags.model('~/jags/b312/incomet.k.bug', data=income.data.jags.k)
update(jags.incomet.k,1000)
res.incomet.k <- coda.samples(jags.incomet.k, c('alpha','beta','sigma2','delta2','delta3','k'), 1000)
plot(res.incomet.k, ask=TRUE)
summary(res.incomet.k)
 


